@@ -35,6 +35,7 @@ class SitesManager(ManagerMix):
         if result.status_code != 200:
             raise Exception("upload fail on server side\n Server error:"+result.content.decode("ASCII"))
 
-
+    def delete_site(self, site: Site):
+        self.delete(site.url)
 
 
